/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.survey.tool');

org.ametys.survey.tool.SurveyXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {});

org.ametys.survey.tool.SurveyXmlLoader.prototype.processResponse = function(response, node, callback) 
{
	this._nodeTags = {};
	this._nodeTags['survey'] = '';
	this._nodeTags['page'] = '';
	this._nodeTags['question'] = '';
	
	org.ametys.survey.tool.SurveyXmlLoader.superclass.processResponse.call(this, response, node, callback);
}

org.ametys.survey.tool.SurveyXmlLoader.prototype.processAttributes = function(attr)
{
	org.ametys.survey.tool.SurveyXmlLoader.superclass.processAttributes.call(this, attr);
	
	attr.text = attr.label;
	this._getIcons(attr);
	attr.type = attr.tagName;
	
	if (attr.tagName == "question")
    { 
		attr.leaf = true;
    }
}

org.ametys.survey.tool.SurveyXmlLoader.prototype._getIcons = function (attr)
{
	if (attr.tagName == "survey")
	{
		attr.icon = getPluginResourcesUrl('survey') + '/img/survey/survey' + (attr['private'] == 'true' ? '_private' : '') + '_16.png';
		attr.iconLarge = getPluginResourcesUrl('survey') + '/img/survey/survey' + (attr['private'] == 'true'  ? '_private' : '') + '_32.png';
	}
	else if (attr.tagName == "page")
	{
		attr.icon = getPluginResourcesUrl('survey') + '/img/pages/page_16.png';
		attr.iconLarge = getPluginResourcesUrl('survey') + '/img/pages/page_32.png';
	}
	else if (attr.tagName == "question")
    { 
		attr.qType = attr.type;
		
		if (attr.type == 'FREE_TEXT')
		{
			attr.icon = getPluginResourcesUrl('survey') + '/img/questions/input_text_16.png';
			attr.iconLarge = getPluginResourcesUrl('survey') + '/img/questions/input_text_32.png';
		}
		else if (attr.type == 'MULTILINE_FREE_TEXT')
		{
			attr.icon = getPluginResourcesUrl('survey') + '/img/questions/textarea_16.png';
			attr.iconLarge = getPluginResourcesUrl('survey') + '/img/questions/textarea_32.png';
		}
		else if (attr.type == 'SINGLE_CHOICE')
		{
			attr.icon = getPluginResourcesUrl('survey') + '/img/questions/input_radio_16.png';
			attr.iconLarge = getPluginResourcesUrl('survey') + '/img/questions/input_radio_32.png';
		}
		else if (attr.type == 'MULTIPLE_CHOICE')
		{
			attr.icon = getPluginResourcesUrl('survey') + '/img/questions/input_checkbox_16.png';
			attr.iconLarge = getPluginResourcesUrl('survey') + '/img/questions/input_checkbox_32.png';
		}
		else if (attr.type == 'SINGLE_MATRIX' || attr.type == 'MULTIPLE_MATRIX')
		{
			attr.icon = getPluginResourcesUrl('survey') + '/img/questions/matrix_16.png';
			attr.iconLarge = getPluginResourcesUrl('survey') + '/img/questions/matrix_32.png';
		}
		else
		{
			attr.icon = getPluginResourcesUrl('survey') + '/img/questions/question_16.png';
			attr.iconLarge = getPluginResourcesUrl('survey') + '/img/questions/question_32.png';
		}
    }
}

org.ametys.survey.tool.SurveyXmlLoader.prototype.createNode = function(node) 
{
	var attr = {
		tagName :node.tagName
	};

	Ext.each(node.attributes, function(a) {
		attr[a.nodeName] = a.nodeValue;
	});
	
	this._currentXMLNode = node;
	this.processAttributes(attr);
	delete this._currentXMLNode;
	
	if (this.baseAttrs)
    {
        Ext.applyIf(attr, this.baseAttrs);
    }
    if (this.applyLoader !== false)
    {
        attr.loader = this;
    }
    if (typeof attr.uiProvider == 'string')
    {
       attr.uiProvider = this.uiProviders[attr.uiProvider] || eval(attr.uiProvider);
    }
    
    if (attr.tagName == "page" || attr.tagName == "survey")
    {
    	return new Ext.tree.AsyncTreeNode(attr);
    }
    else
    {
    	return new Ext.tree.TreeNode(attr);
    }
}
